@@ -7,6 +7,10 @@
 
 extern crate alloc;
 
+mod graph;
+
+mod mod_source;
+
 /// Common traits used throughout the library
 pub mod traits;
 
@@ -16,6 +20,12 @@ pub mod stream;
 /// Wrapper type to handle contextual channel manipulation for [`crate::stream::Stream`]
 pub mod signal;
 
+/// General purpose oscillator
+pub mod oscillator;
+
+/// Slew rate limiter for [`signal::Signal`] 
+pub mod slew;
+
 /// Most basic building block for non-generated sound
 pub mod clip;
 
